@@ -85,6 +85,7 @@ def main():
                 if msg['type'] == 'rename':
                     lines.append('{file_path}: {line} - changed {old_token} to {new_token}\n'.format(**msg))
                 if msg['type'] == 'fix_docstring':
-                    logging.error('{file_path}: {line} - fixed naming in docstring'.format(**msg))
+                    logging.error('{file_path}: {line} - fixed naming in docstring\n'.format(**msg))
                 if msg['type'] == 'add_docstring':
-                    logging.error('{file_path}: {line} - added docstring'.format(**msg))
+                    logging.error('{file_path}: {line} - added docstring\n'.format(**msg))
+            file.writelines(lines)
